# checkit.js

Useful jQuery plugin that will help to check the browser, mobile device, touch screen, Adobe Flash and more. Easy connection to your project and high speed!

## Install

Download [checkit.js](https://github.com/enjoyiacm/checkit.js/archive/master.zip) from GitHub. Place plugin file to your project folder:
``./path/to/your/project/folder/js/checkit.min.js``

Add to your project template (or something else):

```html
<!-- jQuery 1.11.2 minify version from Google CDN JS -->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.2/jquery.min.js"></script>

<!-- checkit.js minify version -->
<script src="../path/to/your/project/folder/js/checkit.min.js"></script>
```
If you want place plugin via fast CDN (special thanks to [jsDelivr](http://www.jsdelivr.com) project), use this:

```html
<!-- Latest 1.x checkit.js minify version from jsDelivr CDN -->
<script src="https://cdn.jsdelivr.net/jquery.checkit.js/1/checkit.min.js"></script>
```

## Usage

### Detect browser

Desktop browsers:

* ``Chrome()`` [Google Chrome](https://www.google.ru/chrome/browser/desktop/)
* ``Firefox()`` [Mozilla Firefox](https://www.mozilla.org/en-US/firefox/new/)
* ``Opera()`` [Opera](http://www.opera.com/)
* ``Safari()`` [Apple Safari](https://www.apple.com/ru/safari/)
* ``YandexBrowser()`` [Yandex.Browser](https://browser.yandex.ru/)
* ``Vivaldi()`` [Vivaldi](https://vivaldi.com/)

MS Internet Explorer:

* Any versions [MS Internet Explorer](http://windows.microsoft.com/en-us/internet-explorer/download-ie): ``MSIE.any()``
* MS Internet Explorer from 5.x to 10.x versions: ``MSIE.v5()``, ``MSIE.v6()``, ``MSIE.v7()``, ``MSIE.v8()``, ``MSIE.v9()``, ``MSIE.v10()``

Mobile specific browsers:

* ``MSIEMobile()`` MS Internet Explorer Mobile
* ``OperaMini()`` Opera Mini
* ``UCBrowser()`` UC Browser
* ``webOS()`` webOS Browser

Web browser engines:

* ``WebKit()`` WebKit
 
Examples:

```javascript
$(document).ready(function() {
  // Check Google Chrome browser
  if (checkit.Browser.Chrome()) {
    // Code for Google Chrome browser
  }
  else {
    // Code for other browsers excluding Google Chrome
  };
  
  // Check MS Internet Explorer ver. 7 and higher
  if (checkit.Browser.MSIE.v7()) {
    // Code for MS Internet Explorer version 7.x and higher
  }
  else {
    // Code for other browsers excluding MS Internet Explorer version 7.x and higher
  };
  
  // Check all WebKit browsers
  if (checkit.Browser.WebKit()) {
    // Code for all WebKit browsers
  }
  else {
    // Code for other browsers excluding WebKit browsers
  };
});
```

### Detect mobile device

* ``Android()`` Android
* ``iOS()`` Apple iOS
* ``BlackBerry()`` BlackBerry
* ``WindowsPhone()`` Windows Phone
* ``webOS()`` webOS

Examples:

```javascript
$(document).ready(function() {
  // Check Android devices
  if (checkit.Mobile.Android()) {
    // Code for Android mobile devices
  }
  else {
    // Code for other mobile devices excluding Android devices
  };
  
  // Check BlackBerry devices
  if (checkit.Mobile.BlackBerry()) {
    // Code for BlackBerry mobile devices
  }
  else {
    // Code for other mobile devices excluding BlackBerry devices
  };
  
  // Check any mobile device
  if (checkit.Mobile.any()) {
    // Code for any mobile devices
  }
  else {
    // Code for other platforms excluding mobile devices
  };
});
```

### Definition support

* ``HTML5()`` HyperText Markup Language, version 5 (HTML5)
* ``CSS3()`` Cascading Style Sheets, version 3 (CSS3)
* ``Flash()`` Adobe Flash player (install, enabled)
* ``Touch()`` Touch events

Examples:

```javascript
$(document).ready(function() {
  // Check HTML5
  if (checkit.HTML5()) {
    // Code for browsers supported HTML5
  };
});
```

### Other examples

```javascript
$(document).ready(function() {
  // Check mobile version of Google Chrome
  if (checkit.Browser.Chrome() && checkit.Mobile.any()) {
    // Your code here
  };
  
  // Check HTML5 + CSS3 supported browsers
  if (checkit.HTML5() && checkit.CSS3()) {
    // Your code here
  };
});
```

## Developer

Development and maintenance of `checkit.js` project engaged in [Interactive agency «Central marketing»](http://centralmarketing.ru). If you want to write a «thank you» or ask us about something, [use this e-mail](mailto:welcome@iacm.ru).

## Your help

If you want help, we will be glad reviews about `checkit.js` on personal blogs (including Twitter), online media or specialized IT-portals. Thank you!

## License

[The MIT License (MIT)](https://github.com/enjoyiacm/checkit.js/blob/master/LICENSE)
